@@ -110,9 +110,13 @@ void QWaylandLayerSurface::attachPopup(QtWaylandClient::QWaylandShellSurface *po
 
 void QWaylandLayerSurface::applyConfigure()
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 9, 0)
     m_configuring = true;
+#endif
     window()->resizeFromApplyConfigure(m_pendingSize);
+#if QT_VERSION < QT_VERSION_CHECK(6, 9, 0)
     m_configuring = false;
+#endif
 }
 
 void QWaylandLayerSurface::setDesiredSize(const QSize &size)
@@ -163,6 +167,7 @@ void QWaylandLayerSurface::setLayer(uint32_t layer)
         set_layer(layer);
 }
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 9, 0)
 void QWaylandLayerSurface::setWindowGeometry(const QRect &geometry)
 {
     if (m_configuring) {
@@ -171,6 +176,12 @@ void QWaylandLayerSurface::setWindowGeometry(const QRect &geometry)
 
     setDesiredSize(geometry.size());
 }
+#else
+void QWaylandLayerSurface::setWindowSize(const QSize &size)
+{
+    setDesiredSize(size);
+}
+#endif
 
 bool QWaylandLayerSurface::requestActivate()
 {
@@ -220,8 +231,10 @@ void QWaylandLayerSurface::sendExpose()
 {
 #if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
     window()->handleExpose(QRect(QPoint(), m_pendingSize));
-#else
+#elif QT_VERSION < QT_VERSION_CHECK(6, 9, 0)
     window()->sendRecursiveExposeEvent();
+#else
+    window()->updateExposure();
 #endif
 }
 
